from setuptools import setup

setup(
    name="anasim",
    version="0.0.9",
    author="david.sulc",
    author_email="sulda.str@gmail.com",
    # py_modules=['text'],
    # package_dir={'':'anasim'}
    packages=['anasim']
)
